[![Documentation Status](https://readthedocs.org/projects/atlasapprox/badge/?version=latest)](https://apidocs.atlasapprox.org/en/latest/?badge=latest)

Python interface to cell atlas approximations
=============================================
Cell atlases such as Tabula Muris and Tabula Sapiens are multi-organ single cell omics data sets describing entire organisms. A cell atlas approximation is a lossy and lightweight compression of a cell atlas that can be streamed via the internet.

This project enables biologists, doctors, and data scientist to quickly find answers for questions such as:

- *What is the expression of a specific gene in human lung?*
- *What are the marker genes of a specific cell type in mouse pancreas*?
- *What fraction of cells (of a specific type) express a gene of interest?*

In addition to this interface, these questions can be asked in R or in a language agnostic manner using the REST API. See the documentation for more info.

**Documentation**: https://atlasapprox.readthedocs.io/en/latest/python/index.html

**Development**: https://github.com/fabilab/cell_atlas_approximations_API
